Skip to content

CLI Help

Ben Trachtenberg edited this page Aug 6, 2018 · 3 revisions

This output is from Version 1.0.13.prod

-h

usage: QuickConfigTemplates [-h] [-d DEBUG] [-f FOLDER] [-o OUTPUTFILE] [-v]
                            {run_build,run_server,pl_create,rm_create,acl_create}
                            ...

Quick Config Templates

optional arguments:
  -h, --help            show this help message and exit
  -d DEBUG, --debug DEBUG
                        The debug level default is level 3, highest is 1 and
                        lowest is 5, it will also show you your yml data in a
                        JSON format
  -f FOLDER, --folder FOLDER
                        Put output file in a folder, name of the folder
  -o OUTPUTFILE, --outputfile OUTPUTFILE
                        The filename to output config to
  -v, --version         show program's version number and exit

commands:
  Valid commands: a single command is required

  {run_build,run_server,pl_create,rm_create,acl_create}
                        CLI Help
    run_build           Run a config build.
    run_server          Run a server to build configs, this is a dev server
                        only!
    pl_create           Create Prefix-List YML from a Prefix-List
    rm_create           Create Route-Map YML from a Route-Map
    acl_create          Create ACL YML from a ACL

run_build -h

usage: QuickConfigTemplates run_build [-h] [-a] [-b BEGIN [BEGIN ...]] [-c]
                                      [-i INCLUDE [INCLUDE ...]] [-j]
                                      [-p PACKAGE] [-r] [-t TYPEFILE] [-y]
                                      [yml_file [yml_file ...]]

positional arguments:
  yml_file              The name of the yml file of your config, not required
                        if you are using the -a option

optional arguments:
  -h, --help            show this help message and exit
  -a, --auto_build      This option uses a csv only to build a config. If you
                        use this option you are also required to use the -t
                        option.
  -b BEGIN [BEGIN ...], --begin BEGIN [BEGIN ...]
                        Begin config from your selection, like Cisco
  -c, --config_only     Display the config, do not output to file
  -i INCLUDE [INCLUDE ...], --include INCLUDE [INCLUDE ...]
                        Include config from your selection, like Cisco
  -j, --json            Display the config, in JSON format
  -p PACKAGE, --package PACKAGE
                        The zip filename to output the package to
  -r, --remote          Remote builder
  -t TYPEFILE, --typefile TYPEFILE
                        The filename of the csv for variable replacement
  -y, --yml             Display the config, in YML format

run_server -h

usage: QuickConfigTemplates run_server [-h] [-i IP] [-d] [-p PORT] [-u URI]

optional arguments:
  -h, --help            show this help message and exit
  -i IP, --ip IP        The IP to listen on.
  -d, --debug           Debug
  -p PORT, --port PORT  The port to listen on.
  -u URI, --uri URI     The base api uri, default is /qct/api/v1

pl_create -h

usage: QuickConfigTemplates pl_create [-h] [-c] [-r] file_name

positional arguments:
  file_name             The name of the text file the Prefix-List is in.

optional arguments:
  -h, --help            show this help message and exit
  -c, --config_only     Display the output, do not output to file
  -r, --reset_sequences
                        Reset sequence numbers

rm_create -h

usage: QuickConfigTemplates rm_create [-h] [-c] [-r] file_name

positional arguments:
  file_name             The name of the text file the Route-Map is in.

optional arguments:
  -h, --help            show this help message and exit
  -c, --config_only     Display the output, do not output to file
  -r, --reset_sequences
                        Reset sequence numbers

acl_create -h

usage: QuickConfigTemplates acl_create [-h] [-c] [-r] file_name

positional arguments:
  file_name             The name of the text file the ACL is in.

optional arguments:
  -h, --help            show this help message and exit
  -c, --config_only     Display the output, do not output to file
  -r, --reset_sequences
                        Reset sequence numbers

Clone this wiki locally